@@ -16,7 +16,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::QuickTime;
 
-$VERSION = '1.06';
+$VERSION = '1.08';
 
 sub ProcessGoPro($$$);
 sub ProcessString($$$);
@@ -386,6 +386,36 @@ my %addUnits = (
         Binary => 1,
     },
   # ZFOV (APP6,GPMF) - seen: 148.34, 0 (fmt f, Hero8, Max)
+  # the following ref forum12825
+    MUID => {
+        Name => 'MediaUniqueID',
+        PrintConv => q{
+            my @a = split ' ', $val;
+            $_ = sprintf('%.8x',$_) foreach @a;
+            return join('', @a);
+        },
+    },
+    EXPT => 'MaximumShutterAngle',
+    MTRX => 'AccelerometerMatrix',
+    ORIN => 'InputOrientation',
+    ORIO => 'OutputOrientation',
+    UNIF => 'InputUniformity',
+    SROT => 'SensorReadoutTime',
+    # the following are ref https://exiftool.org/forum/index.php?topic=15517.0
+    CORI => { Name => 'CameraOrientation', Binary => 1, Notes => 'quaternions 0-1' },
+    AALP => { Name => 'AudioLevel', Notes => 'dBFS' },
+    GPSA => 'GPSAltitudeSystem', # (eg. 'MSLV')
+    GRAV => { Name => 'GravityVector', Binary => 1 },
+    HUES => 'PrediminantHue',
+    IORI => { Name => 'ImageOrientation', Binary => 1, Notes => 'quaternions 0-1' },
+    # LRVO - ? Part of LRV Frame Skip
+    # LRVS - ? Part of LRV Frame Skip
+    # LSKP - LRV Frame Skip
+    # MSKP - MRV Frame Skip
+    MWET => 'MicrophoneWet',
+    SCEN => 'SceneClassification', # (SNOW,URBA,INDO,WATR,VEGE,BEAC + probability)
+    WNDM => 'WindProcessing',
+    YAVG => 'LumaAverage',
 );
 
 # GoPro GPS5 tags (ref 2) (Hero5,Hero6)
@@ -718,7 +748,7 @@ metadata from GoPro MP4 videos.
 
 =head1 AUTHOR
 
-Copyright 2003-2021, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
