@@ -122,7 +122,7 @@ sub ProcessIND($$)
                 # memory troubles (with its apparent 1 GB limit) if the XMP is larger
                 # than about 400 MB, so guard against this
                 if ($len > 300 * 1024 * 1024) {
-                    my $msg = sprintf('Insanely large XMP (%.0f MB)', $len / (1024 * 1024));
+                    my $msg = sprintf('Insanely large XMP (%.0f MiB)', $len / (1024 * 1024));
                     if ($outfile) {
                         $et->Error($msg, 2) and $err = 1, last;
                     } elsif ($et->Options('IgnoreMinorErrors')) {
@@ -258,7 +258,7 @@ them and the LargeFileSupport option is enabled.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
